@@ -140,7 +140,7 @@ def backtest(
                     ticker
                 )
                 money = trade_list.verify_stop_loss(
-                    str(i), ticker_row["low"], ticker_row["high"]
+                    str(i), ticker, ticker_row["low"], ticker_row["high"]
                 )
                 remaining_capital[ticker] += money
 
@@ -190,7 +190,7 @@ def backtest_and_visualise(
     start_at,
     stop_at,
     capital=10000,
-    commision=0,
+    commission=0,
     slippage_perc=0,
     level=logging.WARNING,
     time_buffer=250,
@@ -203,7 +203,7 @@ def backtest_and_visualise(
         start_at,
         stop_at,
         capital=10000,
-        commision=0,
+        commission=0,
         slippage_perc=0,
         level=logging.WARNING,
         time_buffer=250)
